import csv
import matplotlib.pyplot as plt
from collections import defaultdict

# Datenstruktur für Gruppen
groups = defaultdict(lambda: {'x': [], 'y': []})
"""
default = defaultdict(lambda: {'x': [], 'y': []})
default['a']['x'].append(1)  # ✅ Funktioniert automatisch!
"""

# CSV einlesen
with open('Sleep_health_and_lifestyle_dataset.csv', newline='') as csvfile:
    reader = csv.DictReader(csvfile,  delimiter=';')
    for row in reader:
        x = float(row['Age'])
        y = float(row['Sleep Duration'])
        group = row['BMI Category']
        groups[group]['x'].append(x)
        groups[group]['y'].append(y)

# Farben pro Gruppe (automatisch zugewiesen)
color_list = plt.cm.tab10.colors
group_names = list(groups.keys())

# Plot
plt.figure(figsize=(6, 4))
for i, group in enumerate(group_names):
    plt.scatter(groups[group]['x'], groups[group]['y'],
                label=group, color=color_list[i % len(color_list)])

plt.xlabel('x')
plt.ylabel('y')
plt.title('Age - Sleep Duration - BMI')
plt.legend(title='Gruppe')
plt.grid(True)
plt.tight_layout()
plt.show()
